Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(113)

Unified Diff: webkit/media/crypto/proxy_decryptor.h

Issue 11492003: Encrypted Media: Support Audio Decrypt-Only. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: comments mostly resolved (I believe); need to add/update tests if this looks good Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/media/crypto/proxy_decryptor.h
diff --git a/webkit/media/crypto/proxy_decryptor.h b/webkit/media/crypto/proxy_decryptor.h
index b0833ff1278eb298942b20a9def8c56e72ff1d00..17bdf58b22332d6ed40dc286da6648418f14ec73 100644
--- a/webkit/media/crypto/proxy_decryptor.h
+++ b/webkit/media/crypto/proxy_decryptor.h
@@ -42,15 +42,12 @@ class ProxyDecryptor : public media::Decryptor {
decryptor_ = decryptor.Pass();
}
- // Callback to notify that the decryptor has been created.
- typedef base::Callback<void(Decryptor*)> DecryptorNotificationCB;
-
- // Requests the ProxyDecryptor to notify the decryptor creation through the
- // |decryptor_notification_cb| provided.
- // If |decryptor_notification_cb| is null, the ProxyDecryptor should cancel
- // the existing request and fire it with NULL immediately.
- void RequestDecryptorNotification(
- const DecryptorNotificationCB& decryptor_notification_cb);
+ // Requests the ProxyDecryptor to notify the decryptor when it's ready through
+ // the |decryptor_ready_cb| provided.
+ // If |decryptor_ready_cb| is null, the ProxyDecryptor should cancel the
+ // existing request and fire it with NULL immediately.
+ void RegisterDecryptorReadyNotification(
ddorwin 2012/12/13 05:08:25 I thought we were using "Set".
+ const media::DecryptorReadyCB& decryptor_ready_cb);
// media::Decryptor implementation.
virtual bool GenerateKeyRequest(const std::string& key_system,
@@ -117,7 +114,7 @@ class ProxyDecryptor : public media::Decryptor {
// safe as per the Decryptor interface.
base::Lock lock_;
- DecryptorNotificationCB decryptor_notification_cb_;
+ media::DecryptorReadyCB decryptor_ready_cb_;
// The real decryptor that does decryption for the ProxyDecryptor.
// This pointer is protected by the |lock_|.

Powered by Google App Engine
This is Rietveld 408576698